@@ -68,10 +68,8 @@ echo "${PKGI}: Building the package... (it may take a while)"
 BUILDLOG=/usr/src/${PKGI}/${PKGG}_${VERGG}~local_$(dpkg-architecture -qDEB_HOST_ARCH).build
 echo "${PKGI}: Build log will be saved to ${BUILDLOG}"
 BUILDCMD="dpkg-buildpackage -b -uc >${BUILDLOG} 2>&1"
-CAPSH=$(which capsh) \
-&& ${CAPSH} --secbits=0x14 --drop=cap_dac_read_search,cap_fsetid,cap_kill,cap_setgid,cap_setuid,cap_setpcap,cap_linux_immutable,cap_net_bind_service,cap_net_broadcast,cap_net_admin,cap_net_raw,cap_ipc_lock,cap_ipc_owner,cap_sys_module,cap_sys_rawio,cap_sys_chroot,cap_sys_ptrace,cap_sys_pacct,cap_sys_admin,cap_sys_boot,cap_sys_nice,cap_sys_resource,cap_sys_time,cap_sys_tty_config,cap_mknod,cap_lease,cap_audit_write,cap_audit_control,cap_setfcap,cap_mac_override,cap_mac_admin,cap_syslog-ep --print \
-    -- -c "${BUILDCMD}" \
-|| ${BUILDCMD}
+CAPSH="$(which capsh) --secbits=0x14 --drop=cap_dac_read_search,cap_fsetid,cap_kill,cap_setgid,cap_setuid,cap_setpcap,cap_linux_immutable,cap_net_bind_service,cap_net_broadcast,cap_net_admin,cap_net_raw,cap_ipc_lock,cap_ipc_owner,cap_sys_module,cap_sys_rawio,cap_sys_chroot,cap_sys_ptrace,cap_sys_pacct,cap_sys_admin,cap_sys_boot,cap_sys_nice,cap_sys_resource,cap_sys_time,cap_sys_tty_config,cap_mknod,cap_lease,cap_audit_write,cap_audit_control,cap_setfcap,cap_mac_override,cap_mac_admin,cap_syslog-ep --print --" || CAPSH=/bin/bash
+${CAPSH} -c "${BUILDCMD}"
 
 ## installing
 echo "${PKGI}: Installing..."
